Stan Math Library: stan/math/prim/scal/fun/value_of_rec.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
value_of_rec.hpp File Reference

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
double | stan::math::value_of_rec (const T x)
| Return the value of the specified scalar argument converted to a double value. More...
template<>
double | stan::math::value_of_rec< double > (const double x)
| Return the specified argument. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.